@@ -1,6 +1,6 @@
 import subprocess
 
-my_libraries = ['time', 'openpyxl', 'codecs', 'json', 'zipfile', 'pathlib', 'openai', 'os', 'tkinter', 'shutil']
+my_libraries = ['openpyxl', 'codecs', 'json', 'zipfile', 'pathlib', 'openai', 'os', 'tkinter', 'shutil']
 for module in my_libraries:
     try:
         __import__(module)
@@ -85,12 +85,25 @@ def xls_extract(data, file, base_file_name, json_path):
                     diff2 = set(str(exp_2)) - set(str(exp_1))
                     if (len(diff1) == 0) and (len(diff2) == 0):
                         i['expression'] = exp
-                    ws.append([i['name'], exp_o, i['dataType'] if 'dataType' in i else "No DataType Defined",
-                               i['displayFolder'] if 'displayFolder' in i else "No Folder Defined", i['description']])
+                    if (len(exp_o) != 0):
+                        ws.append([i['name'], exp_o, i['dataType'] if 'dataType' in i else "",
+                                   i['displayFolder'] if 'displayFolder' in i else "No Folder Defined",
+                                   i['description']])
+                    else:
+                        ws.append([i['name'], str(i['expression']), i['dataType'] if 'dataType' in i else "",
+                                   i['displayFolder'] if 'displayFolder' in i else "No Folder Defined",
+                                   i['description']])
                 else:
                     # exp_o=str(i['expression'])
-                    ws.append([i['name'], exp, i['dataType'] if 'dataType' in i else "No DataType Defined",
-                               i['displayFolder'] if 'displayFolder' in i else "No Folder Defined", i['description']])
+                    if (len(exp) != 0):
+                        ws.append([i['name'], exp, i['dataType'] if 'dataType' in i else "No DataType Defined",
+                                   i['displayFolder'] if 'displayFolder' in i else "No Folder Defined",
+                                   i['description']])
+                    else:
+                        ws.append([i['name'], str(i['expression']),
+                                   i['dataType'] if 'dataType' in i else "No DataType Defined",
+                                   i['displayFolder'] if 'displayFolder' in i else "No Folder Defined",
+                                   i['description']])
 
     if (cnt >= 1):
         table = Table(displayName="Table1", ref="A1:E" + str(cnt + 1))
@@ -112,6 +125,8 @@ def xls_extract(data, file, base_file_name, json_path):
         adjusted_width = (len('No measures present in this file') + 2) * 1.2
         ws.column_dimensions["A"].width = adjusted_width
 
+    print(cnt)
+
     source = wb.create_sheet('Source Information')
     i = 0
     if 'tables' in data['model']:
